#

    	tables

    		https://www.researchgate.net/figure/Packet-flow-inside-the-Linux-netlfilter-architecture-when-using-the-Filter-Gateway-and_fig28_273655277

    		iptables:
    			conntrack -> mangle -> NAT -> filter

    		tables:
    			filter:
    				description:
    					filtering and access controls

    				chains:
    					INPUT:

    					FORWARD:

    					OUTPUT:

    			NAT:
    				modifies IP addresses and stuff